# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/pylgs',
                'doc_host': 'https://simonkeys.github.io',
                'git_url': 'https://github.com/simonkeys/pylgs',
                'lib_path': 'pylgs'},
  'syms': { 'pylgs.all': {},
            'pylgs.dmelements': { 'pylgs.dmelements.level_label': ('api/dmelements.html#level_label', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.level_mask_da': ('api/dmelements.html#level_mask_da', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.level_population': ('api/dmelements.html#level_population', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.level_population_mask_da': ( 'api/dmelements.html#level_population_mask_da',
                                                                                 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.levels': ('api/dmelements.html#levels', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.parse_dm_element': ('api/dmelements.html#parse_dm_element', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.population': ('api/dmelements.html#population', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.population_element': ('api/dmelements.html#population_element', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.sum_over_dm': ('api/dmelements.html#sum_over_dm', 'pylgs/dmelements.py'),
                                  'pylgs.dmelements.total_population': ('api/dmelements.html#total_population', 'pylgs/dmelements.py')},
            'pylgs.imports': {},
            'pylgs.lgssystem': { 'pylgs.lgssystem.LGSSystem': ('api/lgssystem.html#lgssystem', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.__init__': ('api/lgssystem.html#lgssystem.__init__', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._builtin_paths': ( 'api/lgssystem.html#lgssystem._builtin_paths',
                                                                               'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._floquet_products': ( 'api/lgssystem.html#lgssystem._floquet_products',
                                                                                  'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._get_path': ('api/lgssystem.html#lgssystem._get_path', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._initial_dm': ( 'api/lgssystem.html#lgssystem._initial_dm',
                                                                            'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._is_valid_dir': ( 'api/lgssystem.html#lgssystem._is_valid_dir',
                                                                              'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._products': ('api/lgssystem.html#lgssystem._products', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._reaction': ('api/lgssystem.html#lgssystem._reaction', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._recoil': ('api/lgssystem.html#lgssystem._recoil', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem._vcc': ('api/lgssystem.html#lgssystem._vcc', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.adaptive_stationary_floquet_model': ( 'api/lgssystem.html#lgssystem.adaptive_stationary_floquet_model',
                                                                                                  'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.adaptive_stationary_model': ( 'api/lgssystem.html#lgssystem.adaptive_stationary_model',
                                                                                          'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.builtins': ('api/lgssystem.html#lgssystem.builtins', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.diagram': ('api/lgssystem.html#lgssystem.diagram', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.info': ('api/lgssystem.html#lgssystem.info', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.instationary_model': ( 'api/lgssystem.html#lgssystem.instationary_model',
                                                                                   'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.numpy_instationary_model': ( 'api/lgssystem.html#lgssystem.numpy_instationary_model',
                                                                                         'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.operator': ('api/lgssystem.html#lgssystem.operator', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.rhs': ('api/lgssystem.html#lgssystem.rhs', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.stationary_floquet_model': ( 'api/lgssystem.html#lgssystem.stationary_floquet_model',
                                                                                         'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.LGSSystem.stationary_model': ( 'api/lgssystem.html#lgssystem.stationary_model',
                                                                                 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.ScipyGCROTMKSpILUSolver': ( 'api/lgssystem.html#scipygcrotmkspilusolver',
                                                                              'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.ScipyGCROTMKSpILUSolver.__init__': ( 'api/lgssystem.html#scipygcrotmkspilusolver.__init__',
                                                                                       'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.ScipyGCROTMKSpILUSolver._solve': ( 'api/lgssystem.html#scipygcrotmkspilusolver._solve',
                                                                                     'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem._to_nmo': ('api/lgssystem.html#_to_nmo', 'pylgs/lgssystem.py'),
                                 'pylgs.lgssystem.optree': ('api/lgssystem.html#optree', 'pylgs/lgssystem.py')},
            'pylgs.pymor.grids': { 'pylgs.pymor.grids.OnedUnstructuredGrid': ( 'api/pymor/grids.html#onedunstructuredgrid',
                                                                               'pylgs/pymor/grids.py'),
                                   'pylgs.pymor.grids.OnedUnstructuredGrid.__init__': ( 'api/pymor/grids.html#onedunstructuredgrid.__init__',
                                                                                        'pylgs/pymor/grids.py'),
                                   'pylgs.pymor.grids.OnedUnstructuredGrid.embeddings': ( 'api/pymor/grids.html#onedunstructuredgrid.embeddings',
                                                                                          'pylgs/pymor/grids.py'),
                                   'pylgs.pymor.grids.OnedUnstructuredGrid.subentities': ( 'api/pymor/grids.html#onedunstructuredgrid.subentities',
                                                                                           'pylgs/pymor/grids.py')},
            'pylgs.pymor.models': { 'pylgs.pymor.models.FourierExpandRules': ( 'api/pymor/models.html#fourierexpandrules',
                                                                               'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.FourierExpandRules.__init__': ( 'api/pymor/models.html#fourierexpandrules.__init__',
                                                                                        'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.FourierExpandRules.action_LincombOperator': ( 'api/pymor/models.html#fourierexpandrules.action_lincomboperator',
                                                                                                      'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.FourierExpandRules.action_recurse': ( 'api/pymor/models.html#fourierexpandrules.action_recurse',
                                                                                              'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.InstationaryModel': ( 'api/pymor/models.html#instationarymodel',
                                                                              'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.InstationaryModel.__init__': ( 'api/pymor/models.html#instationarymodel.__init__',
                                                                                       'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryFloquetModel': ( 'api/pymor/models.html#stationaryfloquetmodel',
                                                                                   'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryFloquetModel.__init__': ( 'api/pymor/models.html#stationaryfloquetmodel.__init__',
                                                                                            'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryFloquetModel._floquet_products': ( 'api/pymor/models.html#stationaryfloquetmodel._floquet_products',
                                                                                                     'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryModel': ( 'api/pymor/models.html#stationarymodel',
                                                                            'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryModel.__init__': ( 'api/pymor/models.html#stationarymodel.__init__',
                                                                                     'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryModel._apply_product': ( 'api/pymor/models.html#stationarymodel._apply_product',
                                                                                           'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.StationaryModel.solve': ( 'api/pymor/models.html#stationarymodel.solve',
                                                                                  'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models._kron_vector': ('api/pymor/models.html#_kron_vector', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.d_term': ('api/pymor/models.html#d_term', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.floquet_expand': ('api/pymor/models.html#floquet_expand', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.floquet_reconstruction_array': ( 'api/pymor/models.html#floquet_reconstruction_array',
                                                                                         'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.floquet_reconstruction_operator': ( 'api/pymor/models.html#floquet_reconstruction_operator',
                                                                                            'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_diagonal_operator': ( 'api/pymor/models.html#fourier_diagonal_operator',
                                                                                      'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_expand': ('api/pymor/models.html#fourier_expand', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_expansion_operator': ( 'api/pymor/models.html#fourier_expansion_operator',
                                                                                       'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_series': ('api/pymor/models.html#fourier_series', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_series_coefficients': ( 'api/pymor/models.html#fourier_series_coefficients',
                                                                                        'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.fourier_space': ('api/pymor/models.html#fourier_space', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.time_space': ('api/pymor/models.html#time_space', 'pylgs/pymor/models.py'),
                                    'pylgs.pymor.models.to_sympy': ('api/pymor/models.html#to_sympy', 'pylgs/pymor/models.py')},
            'pylgs.pymor.operators': { 'pylgs.pymor.operators.DensifyRules': ( 'api/pymor/operators.html#densifyrules',
                                                                               'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.DensifyRules.__init__': ( 'api/pymor/operators.html#densifyrules.__init__',
                                                                                        'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.DensifyRules.action_XarrayMatrixOperator': ( 'api/pymor/operators.html#densifyrules.action_xarraymatrixoperator',
                                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.DensifyRules.action_recurse': ( 'api/pymor/operators.html#densifyrules.action_recurse',
                                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ExpressionParameterFunctional.partial_evaluate': ( 'api/pymor/operators.html#expressionparameterfunctional.partial_evaluate',
                                                                                                                 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.IdentityOperator.__str__': ( 'api/pymor/operators.html#identityoperator.__str__',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.LincombOperator.__init__': ( 'api/pymor/operators.html#lincomboperator.__init__',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.LincombOperator.from_file': ( 'api/pymor/operators.html#lincomboperator.from_file',
                                                                                            'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.LincombOperator.partial_assemble': ( 'api/pymor/operators.html#lincomboperator.partial_assemble',
                                                                                                   'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.LincombOperator.partial_evaluate_coefficients': ( 'api/pymor/operators.html#lincomboperator.partial_evaluate_coefficients',
                                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.LincombOperator.terms': ( 'api/pymor/operators.html#lincomboperator.terms',
                                                                                        'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.Operator.__mul__': ( 'api/pymor/operators.html#operator.__mul__',
                                                                                   'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.Operator._repr_html_': ( 'api/pymor/operators.html#operator._repr_html_',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator': ( 'api/pymor/operators.html#productoperator',
                                                                                  'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.H': ( 'api/pymor/operators.html#productoperator.h',
                                                                                    'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.__init__': ( 'api/pymor/operators.html#productoperator.__init__',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.__str__': ( 'api/pymor/operators.html#productoperator.__str__',
                                                                                          'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.apply': ( 'api/pymor/operators.html#productoperator.apply',
                                                                                        'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.apply_adjoint': ( 'api/pymor/operators.html#productoperator.apply_adjoint',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.as_range_array': ( 'api/pymor/operators.html#productoperator.as_range_array',
                                                                                                 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.as_source_array': ( 'api/pymor/operators.html#productoperator.as_source_array',
                                                                                                  'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ProductOperator.assemble': ( 'api/pymor/operators.html#productoperator.assemble',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator': ( 'api/pymor/operators.html#scaleoperator',
                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.__init__': ( 'api/pymor/operators.html#scaleoperator.__init__',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.__mul__': ( 'api/pymor/operators.html#scaleoperator.__mul__',
                                                                                        'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.__rmul__': ( 'api/pymor/operators.html#scaleoperator.__rmul__',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.__str__': ( 'api/pymor/operators.html#scaleoperator.__str__',
                                                                                        'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.apply': ( 'api/pymor/operators.html#scaleoperator.apply',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.assemble': ( 'api/pymor/operators.html#scaleoperator.assemble',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.ScaleOperator.display_name': ( 'api/pymor/operators.html#scaleoperator.display_name',
                                                                                             'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator': ( 'api/pymor/operators.html#sumoperator',
                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.__init__': ( 'api/pymor/operators.html#sumoperator.__init__',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.__mul__': ( 'api/pymor/operators.html#sumoperator.__mul__',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.__rmul__': ( 'api/pymor/operators.html#sumoperator.__rmul__',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.__str__': ( 'api/pymor/operators.html#sumoperator.__str__',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.apply': ( 'api/pymor/operators.html#sumoperator.apply',
                                                                                    'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.SumOperator.assemble': ( 'api/pymor/operators.html#sumoperator.assemble',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayFunctionalOperator': ( 'api/pymor/operators.html#xarrayfunctionaloperator',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayFunctionalOperator.__init__': ( 'api/pymor/operators.html#xarrayfunctionaloperator.__init__',
                                                                                                    'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayFunctionalOperator.apply': ( 'api/pymor/operators.html#xarrayfunctionaloperator.apply',
                                                                                                 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayFunctionalOperator.assemble': ( 'api/pymor/operators.html#xarrayfunctionaloperator.assemble',
                                                                                                    'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayFunctionalOperator.size': ( 'api/pymor/operators.html#xarrayfunctionaloperator.size',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator': ( 'api/pymor/operators.html#xarraymatrixbasedoperator',
                                                                                            'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.H': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.h',
                                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.__str__': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.__str__',
                                                                                                    'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.apply': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.apply',
                                                                                                  'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.apply_adjoint': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.apply_adjoint',
                                                                                                          'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.as_range_array': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.as_range_array',
                                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.as_source_array': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.as_source_array',
                                                                                                            'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.assemble': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.assemble',
                                                                                                     'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixBasedOperator.display_name': ( 'api/pymor/operators.html#xarraymatrixbasedoperator.display_name',
                                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator': ( 'api/pymor/operators.html#xarraymatrixoperator',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.H': ( 'api/pymor/operators.html#xarraymatrixoperator.h',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.__init__': ( 'api/pymor/operators.html#xarraymatrixoperator.__init__',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator._assemble_lincomb': ( 'api/pymor/operators.html#xarraymatrixoperator._assemble_lincomb',
                                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.apply': ( 'api/pymor/operators.html#xarraymatrixoperator.apply',
                                                                                             'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.apply_adjoint': ( 'api/pymor/operators.html#xarraymatrixoperator.apply_adjoint',
                                                                                                     'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.assemble': ( 'api/pymor/operators.html#xarraymatrixoperator.assemble',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.size': ( 'api/pymor/operators.html#xarraymatrixoperator.size',
                                                                                            'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.sparse': ( 'api/pymor/operators.html#xarraymatrixoperator.sparse',
                                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayMatrixOperator.to_numpy': ( 'api/pymor/operators.html#xarraymatrixoperator.to_numpy',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayVectorSpace.__truediv__': ( 'api/pymor/operators.html#xarrayvectorspace.__truediv__',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.XarrayVectorSpace.range_under': ( 'api/pymor/operators.html#xarrayvectorspace.range_under',
                                                                                                'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._get_space_dims': ( 'api/pymor/operators.html#_get_space_dims',
                                                                                  'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._is_labeled_da': ( 'api/pymor/operators.html#_is_labeled_da',
                                                                                 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._label_dims': ( 'api/pymor/operators.html#_label_dims',
                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._label_dims_with': ( 'api/pymor/operators.html#_label_dims_with',
                                                                                   'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._mapping_str': ( 'api/pymor/operators.html#_mapping_str',
                                                                               'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._ndims': ('api/pymor/operators.html#_ndims', 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._numpy_zero_operator': ( 'api/pymor/operators.html#_numpy_zero_operator',
                                                                                       'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._operator_group_tag': ( 'api/pymor/operators.html#_operator_group_tag',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._operator_html_node': ( 'api/pymor/operators.html#_operator_html_node',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._read_sparse_dataarray': ( 'api/pymor/operators.html#_read_sparse_dataarray',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators._swap_dim_labels': ( 'api/pymor/operators.html#_swap_dim_labels',
                                                                                   'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.contract_ProductOperator': ( 'api/pymor/operators.html#contract_productoperator',
                                                                                           'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.contract_matvec': ( 'api/pymor/operators.html#contract_matvec',
                                                                                  'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.coordinates_to_list': ( 'api/pymor/operators.html#coordinates_to_list',
                                                                                      'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.densify': ('api/pymor/operators.html#densify', 'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.dims_matvec': ( 'api/pymor/operators.html#dims_matvec',
                                                                              'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.expand_IdentityOperator': ( 'api/pymor/operators.html#expand_identityoperator',
                                                                                          'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.expand_ProductOperator': ( 'api/pymor/operators.html#expand_productoperator',
                                                                                         'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.operator_html_tree': ( 'api/pymor/operators.html#operator_html_tree',
                                                                                     'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.replace_item': ( 'api/pymor/operators.html#replace_item',
                                                                               'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.to_matrix_ProductOperator': ( 'api/pymor/operators.html#to_matrix_productoperator',
                                                                                            'pylgs/pymor/operators.py'),
                                       'pylgs.pymor.operators.to_matrix_XarrayMatrixOperator': ( 'api/pymor/operators.html#to_matrix_xarraymatrixoperator',
                                                                                                 'pylgs/pymor/operators.py')},
            'pylgs.pymor.parameters': { 'pylgs.pymor.parameters.ExpressionParameterFunctional.__eq__': ( 'api/pymor/parameters.html#expressionparameterfunctional.__eq__',
                                                                                                         'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.ParameterFunctional.__str__': ( 'api/pymor/parameters.html#parameterfunctional.__str__',
                                                                                                'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules': ( 'api/pymor/parameters.html#simplifyfunctionalrules',
                                                                                            'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules.__init__': ( 'api/pymor/parameters.html#simplifyfunctionalrules.__init__',
                                                                                                     'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules.action_LincombOperator': ( 'api/pymor/parameters.html#simplifyfunctionalrules.action_lincomboperator',
                                                                                                                   'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules.action_ProductParameterFunctional': ( 'api/pymor/parameters.html#simplifyfunctionalrules.action_productparameterfunctional',
                                                                                                                              'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules.action_generic': ( 'api/pymor/parameters.html#simplifyfunctionalrules.action_generic',
                                                                                                           'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.SimplifyFunctionalRules.action_recurse': ( 'api/pymor/parameters.html#simplifyfunctionalrules.action_recurse',
                                                                                                           'pylgs/pymor/parameters.py'),
                                        'pylgs.pymor.parameters.simplify_functionals': ( 'api/pymor/parameters.html#simplify_functionals',
                                                                                         'pylgs/pymor/parameters.py')},
            'pylgs.pymor.timestepping': { 'pylgs.pymor.timestepping.AdamsTimeStepper': ( 'api/pymor/timestepping.html#adamstimestepper',
                                                                                         'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.AdamsTimeStepper.__init__': ( 'api/pymor/timestepping.html#adamstimestepper.__init__',
                                                                                                  'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.AdamsTimeStepper.iterate': ( 'api/pymor/timestepping.html#adamstimestepper.iterate',
                                                                                                 'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.BDFTimeStepper': ( 'api/pymor/timestepping.html#bdftimestepper',
                                                                                       'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.BDFTimeStepper.__init__': ( 'api/pymor/timestepping.html#bdftimestepper.__init__',
                                                                                                'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.BDFTimeStepper.iterate': ( 'api/pymor/timestepping.html#bdftimestepper.iterate',
                                                                                               'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.StiffSwitchingTimeStepper': ( 'api/pymor/timestepping.html#stiffswitchingtimestepper',
                                                                                                  'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.StiffSwitchingTimeStepper.__init__': ( 'api/pymor/timestepping.html#stiffswitchingtimestepper.__init__',
                                                                                                           'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.StiffSwitchingTimeStepper.iterate': ( 'api/pymor/timestepping.html#stiffswitchingtimestepper.iterate',
                                                                                                          'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.TimeStepper.solve': ( 'api/pymor/timestepping.html#timestepper.solve',
                                                                                          'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.init_cvode': ( 'api/pymor/timestepping.html#init_cvode',
                                                                                   'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.init_progress_widget': ( 'api/pymor/timestepping.html#init_progress_widget',
                                                                                             'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.solve_cvode': ( 'api/pymor/timestepping.html#solve_cvode',
                                                                                    'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.tick': ( 'api/pymor/timestepping.html#tick',
                                                                             'pylgs/pymor/timestepping.py'),
                                          'pylgs.pymor.timestepping.update_progress_widget': ( 'api/pymor/timestepping.html#update_progress_widget',
                                                                                               'pylgs/pymor/timestepping.py')},
            'pylgs.pymor.vectorarrays': { 'pylgs.pymor.vectorarrays.Lbl': ( 'api/pymor/vectorarrays.html#lbl',
                                                                            'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray': ( 'api/pymor/vectorarrays.html#xarrayvectorarray',
                                                                                          'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.__mul__': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.__mul__',
                                                                                                  'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray._repr_html_': ( 'api/pymor/vectorarrays.html#xarrayvectorarray._repr_html_',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.array': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.array',
                                                                                                'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.array_labeled_as_source': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.array_labeled_as_source',
                                                                                                                  'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.coords': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.coords',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.data': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.data',
                                                                                               'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.dims': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.dims',
                                                                                               'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.extended_coord_data': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.extended_coord_data',
                                                                                                              'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.extended_dims': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.extended_dims',
                                                                                                        'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.extended_shape': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.extended_shape',
                                                                                                         'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.item': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.item',
                                                                                               'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.reim': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.reim',
                                                                                               'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.shape': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.shape',
                                                                                                'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArray.visualize': ( 'api/pymor/vectorarrays.html#xarrayvectorarray.visualize',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl',
                                                                                              'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.__init__': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.__init__',
                                                                                                       'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.__len__': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.__len__',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl._coords': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl._coords',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl._len': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl._len',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.amax': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.amax',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.append': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.append',
                                                                                                     'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.array': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.array',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.axpy': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.axpy',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.axpy_copy': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.axpy_copy',
                                                                                                        'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.conj': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.conj',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.copy': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.copy',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.delete': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.delete',
                                                                                                     'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.dofs': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.dofs',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.imag': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.imag',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.inner': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.inner',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.lincomb': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.lincomb',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.norm': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.norm',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.norm2': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.norm2',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.pairwise_inner': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.pairwise_inner',
                                                                                                             'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.real': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.real',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.reim': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.reim',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.scal': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.scal',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.scal_copy': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.scal_copy',
                                                                                                        'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.stacked_array': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.stacked_array',
                                                                                                            'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.stacked_data': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.stacked_data',
                                                                                                           'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorArrayImpl.to_numpy': ( 'api/pymor/vectorarrays.html#xarrayvectorarrayimpl.to_numpy',
                                                                                                       'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace': ( 'api/pymor/vectorarrays.html#xarrayvectorspace',
                                                                                          'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.__contains__': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.__contains__',
                                                                                                       'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.__eq__': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.__eq__',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.__hash__': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.__hash__',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.__init__': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.__init__',
                                                                                                   'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.__mul__': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.__mul__',
                                                                                                  'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace._array': ( 'api/pymor/vectorarrays.html#xarrayvectorspace._array',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace._array_factory': ( 'api/pymor/vectorarrays.html#xarrayvectorspace._array_factory',
                                                                                                         'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace._repr_html_': ( 'api/pymor/vectorarrays.html#xarrayvectorspace._repr_html_',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.array_from_fn': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.array_from_fn',
                                                                                                        'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.concatenate': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.concatenate',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.coords': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.coords',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.dim': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.dim',
                                                                                              'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.from_data': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.from_data',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.from_numpy': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.from_numpy',
                                                                                                     'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.from_xarray': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.from_xarray',
                                                                                                      'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.is_scalar': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.is_scalar',
                                                                                                    'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.make_array': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.make_array',
                                                                                                     'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.ones': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.ones',
                                                                                               'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.random': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.random',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.rename': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.rename',
                                                                                                 'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.XarrayVectorSpace.zeros': ( 'api/pymor/vectorarrays.html#xarrayvectorspace.zeros',
                                                                                                'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.____': ( 'api/pymor/vectorarrays.html#____',
                                                                             'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._categorical_dims': ( 'api/pymor/vectorarrays.html#_categorical_dims',
                                                                                          'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._format_slider_labels': ( 'api/pymor/vectorarrays.html#_format_slider_labels',
                                                                                              'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._numerical_dim_sort_order': ( 'api/pymor/vectorarrays.html#_numerical_dim_sort_order',
                                                                                                  'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._numerical_dims': ( 'api/pymor/vectorarrays.html#_numerical_dims',
                                                                                        'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._reim': ( 'api/pymor/vectorarrays.html#_reim',
                                                                              'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays._set_plotly_frame': ( 'api/pymor/vectorarrays.html#_set_plotly_frame',
                                                                                          'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.coord_data_shape': ( 'api/pymor/vectorarrays.html#coord_data_shape',
                                                                                         'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.dataarray_coordinate_data': ( 'api/pymor/vectorarrays.html#dataarray_coordinate_data',
                                                                                                  'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.default_coordinate': ( 'api/pymor/vectorarrays.html#default_coordinate',
                                                                                           'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.make_coordinates': ( 'api/pymor/vectorarrays.html#make_coordinates',
                                                                                         'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.plotly_dataarray': ( 'api/pymor/vectorarrays.html#plotly_dataarray',
                                                                                         'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.transpose_like': ( 'api/pymor/vectorarrays.html#transpose_like',
                                                                                       'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.unlabel_dims': ( 'api/pymor/vectorarrays.html#unlabel_dims',
                                                                                     'pylgs/pymor/vectorarrays.py'),
                                          'pylgs.pymor.vectorarrays.validate_coord_data': ( 'api/pymor/vectorarrays.html#validate_coord_data',
                                                                                            'pylgs/pymor/vectorarrays.py')},
            'pylgs.utilities.basic': { 'pylgs.utilities.basic.filter_args': ( 'api/utilities/basic.html#filter_args',
                                                                              'pylgs/utilities/basic.py'),
                                       'pylgs.utilities.basic.filter_out_args': ( 'api/utilities/basic.html#filter_out_args',
                                                                                  'pylgs/utilities/basic.py'),
                                       'pylgs.utilities.basic.get_item': ('api/utilities/basic.html#get_item', 'pylgs/utilities/basic.py')},
            'pylgs.utilities.formatting': { 'pylgs.utilities.formatting.prefix_format': ( 'api/utilities/formatting.html#prefix_format',
                                                                                          'pylgs/utilities/formatting.py'),
                                            'pylgs.utilities.formatting.significant': ( 'api/utilities/formatting.html#significant',
                                                                                        'pylgs/utilities/formatting.py'),
                                            'pylgs.utilities.formatting.significant_digits': ( 'api/utilities/formatting.html#significant_digits',
                                                                                               'pylgs/utilities/formatting.py')},
            'pylgs.utilities.nbdev': { 'pylgs.utilities.nbdev.AttributeTbl': ( 'api/utilities/nbdev.html#attributetbl',
                                                                               'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.AttributeTbl.__init__': ( 'api/utilities/nbdev.html#attributetbl.__init__',
                                                                                        'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.DictTbl': ('api/utilities/nbdev.html#dicttbl', 'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.DictTbl.__init__': ( 'api/utilities/nbdev.html#dicttbl.__init__',
                                                                                   'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable': ( 'api/utilities/nbdev.html#markdowntable',
                                                                                'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable.__eq__': ( 'api/utilities/nbdev.html#markdowntable.__eq__',
                                                                                       'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable.__init__': ( 'api/utilities/nbdev.html#markdowntable.__init__',
                                                                                         'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable._columns': ( 'api/utilities/nbdev.html#markdowntable._columns',
                                                                                         'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable._hdr_list': ( 'api/utilities/nbdev.html#markdowntable._hdr_list',
                                                                                          'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable._repr_markdown_': ( 'api/utilities/nbdev.html#markdowntable._repr_markdown_',
                                                                                                'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable.hdr_str': ( 'api/utilities/nbdev.html#markdowntable.hdr_str',
                                                                                        'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev.MarkdownTable.params_str': ( 'api/utilities/nbdev.html#markdowntable.params_str',
                                                                                           'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev._bold': ('api/utilities/nbdev.html#_bold', 'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev._list2row': ( 'api/utilities/nbdev.html#_list2row',
                                                                            'pylgs/utilities/nbdev.py'),
                                       'pylgs.utilities.nbdev._split_at': ( 'api/utilities/nbdev.html#_split_at',
                                                                            'pylgs/utilities/nbdev.py')},
            'pylgs.utilities.numpy': { 'pylgs.utilities.numpy.sym_range': ( 'api/utilities/numpy.html#sym_range',
                                                                            'pylgs/utilities/numpy.py')},
            'pylgs.utilities.sparse': { 'pylgs.utilities.sparse.dense_toeplitz': ( 'api/utilities/sparse.html#dense_toeplitz',
                                                                                   'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.kron': ('api/utilities/sparse.html#kron', 'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.restrict_bandwidth': ( 'api/utilities/sparse.html#restrict_bandwidth',
                                                                                       'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse': ('api/utilities/sparse.html#sparse', 'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse2d': ( 'api/utilities/sparse.html#sparse2d',
                                                                             'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse2d_diag': ( 'api/utilities/sparse.html#sparse2d_diag',
                                                                                  'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse2d_identity': ( 'api/utilities/sparse.html#sparse2d_identity',
                                                                                      'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse2d_kronecker_matrix': ( 'api/utilities/sparse.html#sparse2d_kronecker_matrix',
                                                                                              'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse_diag': ( 'api/utilities/sparse.html#sparse_diag',
                                                                                'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse_identity': ( 'api/utilities/sparse.html#sparse_identity',
                                                                                    'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse_kronecker_matrix': ( 'api/utilities/sparse.html#sparse_kronecker_matrix',
                                                                                            'pylgs/utilities/sparse.py'),
                                        'pylgs.utilities.sparse.sparse_toeplitz': ( 'api/utilities/sparse.html#sparse_toeplitz',
                                                                                    'pylgs/utilities/sparse.py')},
            'pylgs.utilities.testing': { 'pylgs.utilities.testing.test_array': ( 'api/utilities/testing.html#test_array',
                                                                                 'pylgs/utilities/testing.py'),
                                         'pylgs.utilities.testing.test_da': ( 'api/utilities/testing.html#test_da',
                                                                              'pylgs/utilities/testing.py')},
            'pylgs.utilities.xarray': { 'pylgs.utilities.xarray.Coordinates.__add__': ( 'api/utilities/xarray.html#coordinates.__add__',
                                                                                        'pylgs/utilities/xarray.py'),
                                        'pylgs.utilities.xarray.Coordinates.complement': ( 'api/utilities/xarray.html#coordinates.complement',
                                                                                           'pylgs/utilities/xarray.py'),
                                        'pylgs.utilities.xarray.Coordinates.contain': ( 'api/utilities/xarray.html#coordinates.contain',
                                                                                        'pylgs/utilities/xarray.py'),
                                        'pylgs.utilities.xarray.Coordinates.intersection': ( 'api/utilities/xarray.html#coordinates.intersection',
                                                                                             'pylgs/utilities/xarray.py'),
                                        'pylgs.utilities.xarray.Coordinates.shape': ( 'api/utilities/xarray.html#coordinates.shape',
                                                                                      'pylgs/utilities/xarray.py'),
                                        'pylgs.utilities.xarray.Coordinates.size': ( 'api/utilities/xarray.html#coordinates.size',
                                                                                     'pylgs/utilities/xarray.py')},
            'pylgs.velocitygroups': { 'pylgs.velocitygroups.VelocityGroups': ( 'api/velocitygroups.html#velocitygroups',
                                                                               'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.__init__': ( 'api/velocitygroups.html#velocitygroups.__init__',
                                                                                        'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.drho_dv': ( 'api/velocitygroups.html#velocitygroups.drho_dv',
                                                                                       'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.identity': ( 'api/velocitygroups.html#velocitygroups.identity',
                                                                                        'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.n_times_1': ( 'api/velocitygroups.html#velocitygroups.n_times_1',
                                                                                         'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.normalize': ( 'api/velocitygroups.html#velocitygroups.normalize',
                                                                                         'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.subdivide': ( 'api/velocitygroups.html#velocitygroups.subdivide',
                                                                                         'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.sum': ( 'api/velocitygroups.html#velocitygroups.sum',
                                                                                   'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.VelocityGroups.velocity_diagonal': ( 'api/velocitygroups.html#velocitygroups.velocity_diagonal',
                                                                                                 'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups._velocity_space': ( 'api/velocitygroups.html#_velocity_space',
                                                                                'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups._vg_da': ('api/velocitygroups.html#_vg_da', 'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups._vg_diagonal': ( 'api/velocitygroups.html#_vg_diagonal',
                                                                             'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups._vg_identity': ( 'api/velocitygroups.html#_vg_identity',
                                                                             'pylgs/velocitygroups.py'),
                                      'pylgs.velocitygroups.velocity_density_vector': ( 'api/velocitygroups.html#velocity_density_vector',
                                                                                        'pylgs/velocitygroups.py')}}}
